
Name:           glueminisat
Version:        2.2.8
Release:        6%{?dist}
Summary:        Boolean SAT solver that implements literal blocks distance (LBD)

License:        MIT
Group:          Applications/Engineering
URL:            http://glueminisat.nabelab.org/
# Fetching the URL below with recent releases of Chromium and Firefox works
# fine. However, fetching it with wget currently fails for me (with the
# message: "File name too long"). Including the -O option with the explicit
# filename for the tar ball seems to work around that issue. The URL provided
# by the GlueMiniSat download page has some additional HTTP GET parameters
# appended to it;  "?attredirects=0&d=1" (without the quotes). RPM doesn't
# seem to like them, so they are omitted from the URL tag value here.
Source0:        https://sites.google.com/a/nabelab.org/glueminisat/home/download/%{name}-%{version}.zip
# Simple test case input (from the 2004 International SAT Competition)
Source1:        %{name}-test.in
# Short HTML document that provides links to various online help resources
Source2:        %{name}-intro.html
# Don't try to set the FPU to double precision unless target CPU supports it
Patch0:         %{name}-FPU.patch
BuildRequires:  zlib-devel
Requires(post):  %{_sbindir}/update-alternatives
Requires(preun): %{_sbindir}/update-alternatives

%description
GlueMiniSat is a boolean, propositional satisfiability (SAT) problem
solver. It is a derivative work of the open source MiniSat 2.2 solver,
and implements a form of the literal blocks distance (LBD) evaluation
criteria to predict the quality of clauses learned when conflicts are
encountered in the search process.

The underlying concepts of literal blocks distance were first introduced
in the paper "Predicting learnt clauses quality in modern SAT solvers"
by Gilles Audemard and Laurent Simon, Proceedings of IJCAI-2009, pages
399-404, 2009. The authors' implementation of LBD, the Glucose 1.0 SAT
solver, performed admirably by placing 2-nd at the International 2009
SAT competition in the Applications (UNSAT) category.

GlueMiniSat uses a slightly restricted concept of LBD, called strict
LBD, and a dynamic restart strategy based on local averages of the
decision levels and the LBDs of learned clauses. Experimental results
show that GlueMiniSat also performs very well on SAT instances that
are unsatisfiable.  GlueMiniSat earned 1-st place at the International
2011 SAT competition in the Applications (UNSAT) category, solving 126
of 142 problem instances.

GlueMiniSat supports the same command line options as MiniSat 2.2 (see the
documentation from the minisat2 package). It can also run as a "clone"
of the MiniSat 2.2 or Glucose 1.0 SAT solvers by specifying the command
line options -minisat or -glucose, respectively.

%prep
%setup -q
%patch0 -p1 -b .orig
cp -p %{SOURCE1} .
cp -p %{SOURCE2} .

%build
# Build the "core" executable, (which omits the simplification capabilities)
# The target "r" signifies that we are building the "release" version
make %{?_smp_mflags} -C code/core r \
  MROOT=`pwd`/code \
  COPTIMIZE="${RPM_OPT_FLAGS}" \
  LFLAGS="${RPM_OPT_FLAGS} -lz"
cp -p code/core/%{name}-core-release %{name}_core
# Build the "simp" executable, (which includes the simplification capabilities)
# The target "r" signifies that we are building the "release" version
make %{?_smp_mflags} -C code/simp r \
  MROOT=`pwd`/code \
  COPTIMIZE="${RPM_OPT_FLAGS}" \
  LFLAGS="${RPM_OPT_FLAGS} -lz"
cp -p code/simp/%{name}-simp-release %{name}_simp

%install
mkdir -p ${RPM_BUILD_ROOT}%{_bindir}
# Install %{name}_core as a specific alternative for the generic name %{name}
install -m 0755 %{name}_core ${RPM_BUILD_ROOT}%{_bindir}/%{name}_core
# Install %{name}_simp as a specific alternative for the generic name %{name}
install -m 0755 %{name}_simp ${RPM_BUILD_ROOT}%{_bindir}/%{name}_simp
# Touch the generic path name (to be installed as a ghosted file)
touch ${RPM_BUILD_ROOT}%{_bindir}/%{name}
# Installation/removal in the alternatives system is done by post/preun below

%check
# The test file "glueminisat-test.in" is a brief quote from
# http://www.satcompetition.org/2004/format-solvers2004.html
# Exit value is 10 for satisfiable, 20 for unsatisfiable
./glueminisat_core glueminisat-test.in glueminisat-test-core.out || true
echo "TEST RESULTS (core):"
cat glueminisat-test-core.out
result_core=`head -1 glueminisat-test-core.out`
./glueminisat_simp glueminisat-test.in glueminisat-test-simp.out || true
echo "TEST RESULTS (simp):"
cat glueminisat-test-simp.out
result_simp=`head -1 glueminisat-test-simp.out`
if [ "$result_core" = "SAT" -a "$result_simp" = "SAT" ]; then
  echo "SUCCESS - all of the tests succeeded."
  true
else
  echo "Failed one or more of the tests."
  false
fi

%post
# Setup the alternatives for %{name}
%{_sbindir}/update-alternatives \
  --install %{_bindir}/%{name} %{name} %{_bindir}/%{name}_simp 60
%{_sbindir}/update-alternatives \
  --install %{_bindir}/%{name} %{name} %{_bindir}/%{name}_core 40

%preun
if [ $1 -eq 0 ]; then
  # package removal, not an upgrade
  %{_sbindir}/update-alternatives \
  --remove %{name} %{_bindir}/%{name}_core
  %{_sbindir}/update-alternatives \
  --remove %{name} %{_bindir}/%{name}_simp
fi

%files
%doc license.txt readme.txt %{name}-intro.html
%doc %{name}-test.in %{name}-test-core.out %{name}-test-simp.out
%attr(755,root,root) %{_bindir}/%{name}_core
%attr(755,root,root) %{_bindir}/%{name}_simp
%ghost %{_bindir}/%{name}

%changelog
* Wed Feb 07 2018 Fedora Release Engineering <releng@fedoraproject.org> - 2.2.8-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Wed Aug 02 2017 Fedora Release Engineering <releng@fedoraproject.org> - 2.2.8-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild

* Wed Jul 26 2017 Fedora Release Engineering <releng@fedoraproject.org> - 2.2.8-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Fri Feb 10 2017 Fedora Release Engineering <releng@fedoraproject.org> - 2.2.8-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Wed Feb 03 2016 Fedora Release Engineering <releng@fedoraproject.org> - 2.2.8-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Wed Jan 27 2016 John C. Peterson <jcp@eskimo.com> - 2.2.8-1
- Updated to the most recent release from upstream, now distributed in zip fmt
- Updated the glueminisat-FPU.patch (some line numbers had shifted too much)
- Removed the (sed) patches to code/mtl/template.mk (it's not needed anymore)
- Removed the glueminisat-printf.patch (too much trouble to keep up with it)
- Build for Fedora 23

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.2.7-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Sat May 02 2015 Kalev Lember <kalevlember@gmail.com> - 2.2.7-4
- Rebuilt for GCC 5 C++11 ABI change

* Sat Aug 16 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.2.7-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.2.7-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Tue Aug 13 2013 John C. Peterson <jcp@eskimo.com> - 2.2.7-1
- Updated to the latest release from upstream. Some of the fixes from the
  previous glueminisat-printf.patch were incorporated by upstream into 2.2.7.
  Modified the patch to address new problems of a similar (cosmetic) nature.
- Now builds both the "core" and "simp" executables and installs them as
  alternatives for the generic executable named "glueminisat".
- Some minor changes to the build process to support the alternatives.
- Eliminated the -ffloat-store compiler option (as it's configured at runtime)

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.2.5-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Wed Feb 13 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.2.5-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Thu Jul 19 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.2.5-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Wed Apr 25 2012 John C. Peterson <jcp@eskimo.com> - 2.2.5-3
- Wrote an HTML "intro" document with links to David Wheeler's MiniSat tutorial
- Fixed minor typo error in the comments about the URL tag value
- Added some additional information to the package description

* Tue Apr 24 2012 John C. Peterson <jcp@eskimo.com> - 2.2.5-2
- Replaced the usage of redundant global "myname" with standard macro "name"
- Replaced the occurrences of glueminisat with "name" macro in source, patches
- Sent the patches to upstream (Hidetomo Nabeshima, the primary author)
- Addition to glueminisat-printf.patch (based on feedback from author)

* Sat Apr 14 2012 John C. Peterson <jcp@eskimo.com> - 2.2.5-1
- Note that GlueMiniSat is a derivative work of the MiniSat 2.2 SAT solver
- Initial RPM spec file is based on the one from the Fedora minisat2 package
- Cosmetic patch to keep progress messages under 80 characters (avoids wrap)
- Adapted the FPU patch from the Fedora minisat2 package

